@@ -1169,7 +1169,7 @@ void QuicClientTransport::recvMsg(
     struct sockaddr_storage addrStorage {};
     if (!server) {
       rawAddr = reinterpret_cast<sockaddr*>(&addrStorage);
-      rawAddr->sa_family = sock.address().getFamily();
+      rawAddr->sa_family = sock.getLocalAddressFamily();
     }
 
     int flags = 0;
@@ -1444,74 +1444,9 @@ void QuicClientTransport::recvMmsg(
       networkData.getPackets().size(), networkData.getTotalData());
 }
 
-void QuicClientTransport::onNotifyDataAvailable(
-    QuicAsyncUDPSocket& sock) noexcept {
-  auto self = this->shared_from_this();
-  CHECK(conn_) << "trying to receive packets without a connection";
-  auto readBufferSize =
-      conn_->transportSettings.maxRecvPacketSize * numGROBuffers_;
-  const uint16_t numPackets = conn_->transportSettings.maxRecvBatchSize;
-
-  NetworkData networkData;
-  networkData.reserve(numPackets);
-  size_t totalData = 0;
-  Optional<folly::SocketAddress> server;
-
-  if (conn_->transportSettings.shouldUseWrapperRecvmmsgForBatchRecv) {
-    const auto result = sock.recvmmsgNetworkData(
-        readBufferSize, numPackets, networkData, server, totalData);
-
-    // track the received packets
-    for (const auto& packet : networkData.getPackets()) {
-      if (packet.buf.empty()) {
-        continue;
-      }
-      auto len = packet.buf.chainLength();
-      maybeQlogDatagram(len);
-    }
-    trackDatagramsReceived(
-        networkData.getPackets().size(), networkData.getTotalData());
-
-    // Propagate errors
-    // TODO(bschlinker): Investigate generalization of loopDetectorCallback
-    // TODO(bschlinker): Consider merging this into ReadCallback
-    if (result.maybeNoReadReason) {
-      const auto& noReadReason = result.maybeNoReadReason.value();
-      switch (noReadReason) {
-        case NoReadReason::RETRIABLE_ERROR:
-          if (conn_->loopDetectorCallback) {
-            conn_->readDebugState.noReadReason = NoReadReason::RETRIABLE_ERROR;
-          }
-          break;
-        case NoReadReason::NONRETRIABLE_ERROR:
-          // If we got a non-retriable error, we might have received
-          // a packet that we could process, however let's just quit early.
-          sock.pauseRead();
-          if (conn_->loopDetectorCallback) {
-            conn_->readDebugState.noReadReason =
-                NoReadReason::NONRETRIABLE_ERROR;
-          }
-          onReadError(folly::AsyncSocketException(
-              folly::AsyncSocketException::INTERNAL_ERROR,
-              "::recvmmsg() failed",
-              errno));
-          break;
-        case NoReadReason::READ_OK:
-        case NoReadReason::EMPTY_DATA:
-        case NoReadReason::TRUNCATED:
-        case NoReadReason::STALE_DATA:
-          break;
-      }
-    }
-  } else if (conn_->transportSettings.shouldUseRecvmmsgForBatchRecv) {
-    // TODO(bschlinker): Deprecate in favor of Wrapper::recvmmsg
-    recvmmsgStorage_.resize(numPackets);
-    recvMmsg(sock, readBufferSize, numPackets, networkData, server, totalData);
-  } else {
-    // TODO(bschlinker): Deprecate in favor of Wrapper::recvmmsg
-    recvMsg(sock, readBufferSize, numPackets, networkData, server, totalData);
-  }
-
+void QuicClientTransport::processPackets(
+    NetworkData&& networkData,
+    const Optional<folly::SocketAddress>& server) {
   if (networkData.getPackets().empty()) {
     // recvMmsg and recvMsg might have already set the reason and counter
     if (conn_->loopDetectorCallback) {
@@ -1534,6 +1469,145 @@ void QuicClientTransport::onNotifyDataAvailable(
   onNetworkData(*server, std::move(networkData));
 }
 
+void QuicClientTransport::readWithRecvmmsgWrapper(
+    QuicAsyncUDPSocket& sock,
+    uint64_t readBufferSize,
+    uint16_t numPackets) {
+  NetworkData networkData;
+  networkData.reserve(numPackets);
+  size_t totalData = 0;
+  Optional<folly::SocketAddress> server;
+
+  const auto result = sock.recvmmsgNetworkData(
+      readBufferSize, numPackets, networkData, server, totalData);
+
+  // track the received packets
+  for (const auto& packet : networkData.getPackets()) {
+    if (packet.buf.empty()) {
+      continue;
+    }
+    auto len = packet.buf.chainLength();
+    maybeQlogDatagram(len);
+  }
+  trackDatagramsReceived(
+      networkData.getPackets().size(), networkData.getTotalData());
+
+  // Propagate errors
+  // TODO(bschlinker): Investigate generalization of loopDetectorCallback
+  // TODO(bschlinker): Consider merging this into ReadCallback
+  if (result.maybeNoReadReason) {
+    const auto& noReadReason = result.maybeNoReadReason.value();
+    switch (noReadReason) {
+      case NoReadReason::RETRIABLE_ERROR:
+        if (conn_->loopDetectorCallback) {
+          conn_->readDebugState.noReadReason = NoReadReason::RETRIABLE_ERROR;
+        }
+        break;
+      case NoReadReason::NONRETRIABLE_ERROR:
+        // If we got a non-retriable error, we might have received
+        // a packet that we could process, however let's just quit early.
+        sock.pauseRead();
+        if (conn_->loopDetectorCallback) {
+          conn_->readDebugState.noReadReason = NoReadReason::NONRETRIABLE_ERROR;
+        }
+        onReadError(folly::AsyncSocketException(
+            folly::AsyncSocketException::INTERNAL_ERROR,
+            "::recvmmsg() failed",
+            errno));
+        break;
+      case NoReadReason::READ_OK:
+      case NoReadReason::EMPTY_DATA:
+      case NoReadReason::TRUNCATED:
+      case NoReadReason::STALE_DATA:
+        break;
+    }
+  }
+  processPackets(std::move(networkData), server);
+}
+
+void QuicClientTransport::readWithRecvmmsg(
+    QuicAsyncUDPSocket& sock,
+    uint64_t readBufferSize,
+    uint16_t numPackets) {
+  NetworkData networkData;
+  networkData.reserve(numPackets);
+  size_t totalData = 0;
+  Optional<folly::SocketAddress> server;
+
+  // TODO(bschlinker): Deprecate in favor of Wrapper::recvmmsg
+  recvmmsgStorage_.resize(numPackets);
+  recvMmsg(sock, readBufferSize, numPackets, networkData, server, totalData);
+
+  processPackets(std::move(networkData), server);
+}
+
+void QuicClientTransport::readWithRecvmsgSinglePacketLoop(
+    QuicAsyncUDPSocket& sock,
+    uint64_t readBufferSize) {
+  size_t totalData = 0;
+  Optional<folly::SocketAddress> server;
+  for (size_t i = 0; i < conn_->transportSettings.maxRecvBatchSize; i++) {
+    auto networkDataSinglePacket = NetworkData();
+    networkDataSinglePacket.reserve(1);
+    recvMsg(
+        sock,
+        readBufferSize,
+        1 /* numPackets */,
+        networkDataSinglePacket,
+        server,
+        totalData);
+    if (!socket_) {
+      // Socket has been closed.
+      return;
+    }
+    if (networkDataSinglePacket.getPackets().size() == 0) {
+      break;
+    }
+    processPackets(std::move(networkDataSinglePacket), server);
+    if (!socket_) {
+      // Socket has been closed.
+      return;
+    }
+  }
+  // Call updateWriteLooper manually because processPackets()/onNetworkData()
+  // will not schedule it when transportSettings.networkDataPerSocketRead is on.
+  updateWriteLooper(true, conn_->transportSettings.inlineWriteAfterRead);
+}
+
+void QuicClientTransport::readWithRecvmsg(
+    QuicAsyncUDPSocket& sock,
+    uint64_t readBufferSize,
+    uint16_t numPackets) {
+  NetworkData networkData;
+  networkData.reserve(numPackets);
+  size_t totalData = 0;
+  Optional<folly::SocketAddress> server;
+
+  // TODO(bschlinker): Deprecate in favor of Wrapper::recvmmsg
+  recvMsg(sock, readBufferSize, numPackets, networkData, server, totalData);
+
+  processPackets(std::move(networkData), server);
+}
+
+void QuicClientTransport::onNotifyDataAvailable(
+    QuicAsyncUDPSocket& sock) noexcept {
+  auto self = this->shared_from_this();
+  CHECK(conn_) << "trying to receive packets without a connection";
+  auto readBufferSize =
+      conn_->transportSettings.maxRecvPacketSize * numGROBuffers_;
+  const uint16_t numPackets = conn_->transportSettings.maxRecvBatchSize;
+
+  if (conn_->transportSettings.shouldUseWrapperRecvmmsgForBatchRecv) {
+    readWithRecvmmsgWrapper(sock, readBufferSize, numPackets);
+  } else if (conn_->transportSettings.shouldUseRecvmmsgForBatchRecv) {
+    readWithRecvmmsg(sock, readBufferSize, numPackets);
+  } else if (conn_->transportSettings.networkDataPerSocketRead) {
+    readWithRecvmsgSinglePacketLoop(sock, readBufferSize);
+  } else {
+    readWithRecvmsg(sock, readBufferSize, numPackets);
+  }
+}
+
 void QuicClientTransport::
     happyEyeballsConnAttemptDelayTimeoutExpired() noexcept {
   // Declare 0-RTT data as lost so that they will be retransmitted over the
@@ -1795,4 +1869,12 @@ void QuicClientTransport::RecvmmsgStorage::resize(size_t numPackets) {
   }
 }
 
+uint64_t QuicClientTransport::getNumAckFramesSent() const {
+  return conn_->numAckFramesSent;
+}
+
+uint64_t QuicClientTransport::getNumFlowControlFramesSent() const {
+  return conn_->numWindowUpdateFramesSent;
+}
+
 } // namespace quic
