@@ -34,7 +34,6 @@ class CopaTest : public Test {
           Clock::now(),
           10,
           0,
-          false,
           totalSentBytes,
           0,
           LossState(),
@@ -59,7 +58,6 @@ class CopaTest : public Test {
         Clock::now(),
         size,
         0,
-        false,
         totalSent,
         inflight,
         LossState(),
@@ -123,7 +121,7 @@ class CopaTest : public Test {
 
     // ack for first packet, lastCwndDoubleTime_ will be initialized now
     copa.onPacketAckOrLoss(
-        createAckEvent(packetNumToAck, packetSize, now), folly::none);
+        createAckEvent(packetNumToAck, packetSize, now), none);
     numPacketsInFlight--;
     EXPECT_EQ(copa.getBytesInFlight(), numPacketsInFlight * packetSize);
 
@@ -145,7 +143,7 @@ class CopaTest : public Test {
     conn.lossState.srtt = 100ms;
 
     copa.onPacketAckOrLoss(
-        createAckEvent(packetNumToAck, packetSize, now), folly::none);
+        createAckEvent(packetNumToAck, packetSize, now), none);
     packetNumToAck++;
     EXPECT_FALSE(copa.inSlowStart());
     uint64_t cwndChange =
@@ -202,7 +200,7 @@ TEST_F(CopaTest, PersistentCongestion) {
   CongestionController::LossEvent loss;
   loss.persistentCongestion = true;
   loss.addLostPacket(pkt);
-  copa.onPacketAckOrLoss(folly::none, loss);
+  copa.onPacketAckOrLoss(none, loss);
   EXPECT_EQ(
       copa.getWritableBytes(),
       conn.transportSettings.minCwndInMss * conn.udpSendPacketLen);
@@ -282,8 +280,7 @@ TEST_F(CopaTest, TestSlowStartAck) {
   conn.lossState.srtt = 280ms;
 
   // ack for first packet, lastCwndDoubleTime_ will be initialized now
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   numPacketsInFlight--;
   EXPECT_EQ(copa.getBytesInFlight(), numPacketsInFlight * packetSize);
 
@@ -303,11 +300,9 @@ TEST_F(CopaTest, TestSlowStartAck) {
 
   auto lastCwnd = copa.getCongestionWindow();
   // Say more time passed and some packets were acked meanwhile.
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
   now += 300ms;
 
@@ -316,8 +311,7 @@ TEST_F(CopaTest, TestSlowStartAck) {
   // RTTmin = 280ms
   conn.lossState.srtt = 300ms;
 
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
   now += 100ms;
 
@@ -328,8 +322,7 @@ TEST_F(CopaTest, TestSlowStartAck) {
 
   // ack for 5th packet, at this point currentRate < targetRate, but not enough
   // time has passed for cwnd to double again in slow start
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   EXPECT_TRUE(copa.inSlowStart());
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd);
 
@@ -343,8 +336,7 @@ TEST_F(CopaTest, TestSlowStartAck) {
 
   // ack for 6th packet, at this point even though lrtt has increased, standing
   // rtt hasn't. Hence it will still not exit slow start
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   EXPECT_TRUE(copa.inSlowStart());
   // cwnd = 40 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd);
@@ -356,8 +348,7 @@ TEST_F(CopaTest, TestSlowStartAck) {
 
   // ack for 7th packet, at this point currentRate > targetRate, so it would
   // exit slow start and reduce cwnd
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   EXPECT_FALSE(copa.inSlowStart());
   EXPECT_LE(copa.getCongestionWindow(), lastCwnd);
 }
@@ -380,8 +371,7 @@ TEST_F(CopaTest, TestSteadyStateChanges) {
   conn.lossState.lrtt = 100ms;
   // Rttmin = 100ms
   conn.lossState.srtt = 100ms;
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
   uint64_t cwndChange =
       cwndChangeSteadyState(lastCwnd, 1.0, packetSize, 0.5, conn);
@@ -395,8 +385,7 @@ TEST_F(CopaTest, TestSteadyStateChanges) {
   conn.lossState.lrtt = 50ms;
   // Rttmin = 60ms
   conn.lossState.srtt = 100ms;
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
   cwndChange = cwndChangeSteadyState(lastCwnd, 1.0, packetSize, 0.5, conn);
   // cwnd = 9.6 + 1 / (0.5 * 9.6) = 9.8 packets
@@ -408,8 +397,7 @@ TEST_F(CopaTest, TestSteadyStateChanges) {
   // Rttmin = 60ms
   conn.lossState.srtt = 100ms;
   // Though lrtt has increased, rtt standing has not.  Will still increase
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
   cwndChange = cwndChangeSteadyState(lastCwnd, 1.0, packetSize, 0.5, conn);
   // cwnd = 9.8 + 1 / (0.5 * 9.8) = 10.0 packets
@@ -418,8 +406,7 @@ TEST_F(CopaTest, TestSteadyStateChanges) {
 
   // If sufficient time has elapsed, the increased rtt will be noted
   now += 110ms;
-  copa.onPacketAckOrLoss(
-      createAckEvent(packetNumToAck, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(packetNumToAck, packetSize, now), none);
   packetNumToAck++;
   cwndChange = cwndChangeSteadyState(lastCwnd, 1.0, packetSize, 0.5, conn);
   // cwnd = 10 - 1 / (0.5 * 10) = 9.8
@@ -451,7 +438,7 @@ TEST_F(CopaTest, TestVelocity) {
   conn.lossState.srtt = 100ms;
   now += 100ms;
   // velocity = 1, direction = 0
-  copa.onPacketAckOrLoss(createAckEvent(30, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(30, packetSize, now), none);
 
   uint64_t cwndChange =
       cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
@@ -461,7 +448,7 @@ TEST_F(CopaTest, TestVelocity) {
 
   // another ack, velocity = 1, direction 0 -> 1
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(35, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(35, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 10 + 1 / (0.5 * 10) = 10.2 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -469,7 +456,7 @@ TEST_F(CopaTest, TestVelocity) {
 
   // another ack, velocity = 1, direction = 1
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(40, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(40, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 10.2 + 1 / (0.5 * 10.2) = 10.4 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -477,7 +464,7 @@ TEST_F(CopaTest, TestVelocity) {
 
   // another ack, velocity = 1, direction = 1
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(45, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(45, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 10.4 + 1 / (0.5 * 10.4) = 10.6 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -485,7 +472,7 @@ TEST_F(CopaTest, TestVelocity) {
 
   // another ack, velocity = 1, direction = 1
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(50, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(50, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 10.4 + 1 / (0.5 * 10.4) = 10.6 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -494,7 +481,7 @@ TEST_F(CopaTest, TestVelocity) {
   // another ack, velocity = 2, direction = 1
   velocity = 2 * velocity;
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(55, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(55, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 10 + 2 / (0.5 * 10.6) = 11 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -503,7 +490,7 @@ TEST_F(CopaTest, TestVelocity) {
   // another ack, velocity = 4, direction = 1
   velocity = 2 * velocity;
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(60, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(60, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 11 + 4 / (0.5 * 11) = 11.8 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -512,7 +499,7 @@ TEST_F(CopaTest, TestVelocity) {
   // another ack, velocity = 8, direction = 1
   velocity = 2 * velocity;
   now += 100ms;
-  copa.onPacketAckOrLoss(createAckEvent(65, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(65, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 11.8 + 8 / (0.5 * 11.8) = 13.4 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd + cwndChange);
@@ -526,7 +513,7 @@ TEST_F(CopaTest, TestVelocity) {
   velocity = 1;
   // give it some extra time for rtt standing to reset
   now += 110ms;
-  copa.onPacketAckOrLoss(createAckEvent(50, packetSize, now), folly::none);
+  copa.onPacketAckOrLoss(createAckEvent(50, packetSize, now), none);
   cwndChange = cwndChangeSteadyState(lastCwnd, velocity, packetSize, 0.5, conn);
   // cwnd = 11.8 + 8 / (0.5 * 11.8) = 13.4 packets
   EXPECT_EQ(copa.getCongestionWindow(), lastCwnd - cwndChange);
@@ -577,7 +564,7 @@ TEST_F(CopaTest, PacketLossInvokesPacer) {
   EXPECT_CALL(*rawPacer, onPacketsLoss()).Times(1);
   CongestionController::LossEvent lossEvent;
   lossEvent.addLostPacket(packet);
-  copa.onPacketAckOrLoss(folly::none, lossEvent);
+  copa.onPacketAckOrLoss(none, lossEvent);
 }
 
 } // namespace test
